"use strict";
/*
 * Copyright 2022 Adobe, Inc.
 *
 * Your access and use of this software is governed by the Adobe Customer Feedback Program Terms and Conditions or other Beta License Agreement signed by your employer and Adobe, Inc.. This software is NOT open source and may not be used without one of the foregoing licenses. Even with a foregoing license, your access and use of this file is limited to the earlier of (a) 180 days, (b) general availability of the product(s) which utilize this software (i.e. AEM Forms), (c) January 1, 2023, (d) Adobe providing notice to you that you may no longer use the software or that your beta trial has otherwise ended.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL ADOBE NOR ITS THIRD PARTY PROVIDERS AND PARTNERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Field_1 = __importDefault(require("./Field"));
const ValidationUtils_1 = require("./utils/ValidationUtils");
/**
 * @param offValue
 * @private
 */
const requiredConstraint = (offValue) => (constraint, value) => {
    const valid = ValidationUtils_1.Constraints.required(constraint, value).valid && (!constraint || value != offValue);
    return { valid, value };
};
/**
 * Implementation of check box runtime model which extends from {@link Field | field} model
 */
class Checkbox extends Field_1.default {
    offValue() {
        const opts = this.enum;
        return opts.length > 1 ? opts[1] : null;
    }
    /**
     * @private
     */
    _getConstraintObject() {
        const baseConstraints = Object.assign({}, super._getConstraintObject());
        baseConstraints.required = requiredConstraint(this.offValue());
        return baseConstraints;
    }
    _getDefaults() {
        return Object.assign(Object.assign({}, super._getDefaults()), { enforceEnum: true });
    }
    /**
     * Returns the `enum` constraints from the json
     */
    get enum() {
        return this._jsonModel.enum || [];
    }
}
exports.default = Checkbox;
