"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormTreeProvider = void 0;
const vscode = __importStar(require("vscode"));
const json = __importStar(require("jsonc-parser"));
const path = __importStar(require("path"));
const utils_1 = require("./utils");
const af_core_1 = require("@aemforms/af-core");
const fieldTypes = [
    "text-input",
    "number-input",
    "date-input",
    "file-input",
    "multiline-input",
    "drop-down",
    "radio-button",
    "checkbox-group",
    "checkbox",
    "plain-text",
    "submit",
    "panel"
];
const defaults = {
    "all": {
        "name": "new_field",
        "label": {
            "value": ""
        },
        "description": "",
        "type": "string",
        "required": false
    },
    'number-input': {
        "type": "number",
        "minimum": 0,
        "maximum": 100
    },
    'date-input': {
        "type": "string",
        "minimum": "2020-10-10",
        "maximum": "2021-10-10",
        "format": "date"
    },
    'file-input': {
        "type": "file",
        "maxFileSize": "2MB",
        "accept": ["image/*"]
    },
    "checkbox": {
        "type": "boolean",
        "enum": [true, false],
    },
    "checkbox-group": {
        "enum": [],
        "enumNames": []
    },
    "radio-button": {
        "enum": [],
        "enumNames": []
    },
    "drop-down": {
        "enum": [],
        "enumNames": []
    },
    "panel": {
        "type": "object",
        "items": []
    },
    "submit": {
        "type": "button",
        "label": {
            "value": "Submit"
        },
        "events": {
            "click": "dispatch_event($form, 'submit')"
        }
    }
};
class FormTreeProvider {
    constructor(context) {
        this.context = context;
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
        this.autoRefresh = true;
        vscode.window.onDidChangeActiveTextEditor(() => this.onActiveEditorChanged());
        vscode.workspace.onDidChangeTextDocument(e => this.onDocumentChanged(e));
        this.autoRefresh = vscode.workspace.getConfiguration('formTree').get('autorefresh');
        vscode.workspace.onDidChangeConfiguration(() => {
            this.autoRefresh = vscode.workspace.getConfiguration('formTree').get('autorefresh');
        });
        this.onActiveEditorChanged();
    }
    refresh(offset) {
        this.parseTree();
        if (offset) {
            this._onDidChangeTreeData.fire(offset);
        }
        else {
            this._onDidChangeTreeData.fire(undefined);
        }
    }
    delete(offset) {
        this.editor.edit(editBuilder => {
            const path = json.getLocation(this.text, offset.offset).path;
            let fieldNode = json.findNodeAtLocation(this.tree, path);
            const parent = fieldNode.parent;
            const edits = json.modify(this.text, path, undefined, {});
            edits.forEach(e => {
                const range = new vscode.Range(this.editor.document.positionAt(e.offset), this.editor.document.positionAt(e.offset + e.length));
                editBuilder.replace(range, "");
            });
            setTimeout(() => {
                this.parseTree();
                this.refresh(undefined);
            }, 100);
        });
    }
    translate() {
        this.editor.edit(editBuilder => {
            var _a;
            this.text = this.editor.document.getText();
            var formObj = JSON.parse(this.text);
            const [newObj, langObj] = (0, af_core_1.createTranslationObject)(formObj);
            // update whole text
            var lineCount = this.editor.document.lineCount;
            var lastLine = this.editor.document.lineAt(lineCount - 1);
            var endPos = lastLine.range.end;
            var range = new vscode.Range(new vscode.Position(0, 0), endPos);
            editBuilder.delete(range);
            editBuilder.insert(new vscode.Position(0, 0), JSON.stringify(newObj, null, 2));
            // write the dictionary to the file system using the name of the current file
            const wsedit = new vscode.WorkspaceEdit();
            const wsPath = (_a = vscode.workspace.workspaceFolders) === null || _a === void 0 ? void 0 : _a[0].uri.fsPath; // gets the path of the first workspace folder
            const currentFile = path.basename(this.editor.document.fileName);
            const extension = path.extname(currentFile);
            const newExtension = `.i18n${extension}`;
            const newFile = currentFile.replace(extension, newExtension);
            const dictionaryPath = path.join(wsPath, "generated", "__localization__", newFile);
            const dictionaryFileUri = vscode.Uri.file(dictionaryPath);
            const content = JSON.stringify(langObj, null, 2);
            var uint8Content = new TextEncoder().encode(content);
            //@ts-ignore
            vscode.workspace.fs.writeFile(dictionaryFileUri, uint8Content, { create: true, overwrite: true }).then(() => {
                vscode.workspace.openTextDocument(dictionaryFileUri).then((t) => {
                    t.save().then(() => {
                        vscode.workspace.applyEdit(wsedit).then(() => {
                            this.editor.document.save().then(() => {
                                setTimeout(() => {
                                    alert(1);
                                    this.parseTree();
                                    this.refresh(undefined);
                                }, 100);
                            });
                        });
                    });
                });
            });
        });
    }
    getFieldType() {
        return vscode.window.showQuickPick(fieldTypes, { title: 'Select the field type' }).then(x => {
            return {
                fieldType: x || 'text-input'
            };
        });
    }
    getFieldName(obj) {
        return vscode.window.showInputBox({ title: 'Select the field name', value: "name", prompt: "Only alphanumeric characters allowed" }).then(x => {
            return Object.assign(Object.assign({}, obj), { name: x || "name" });
        });
    }
    getFieldLabel(obj) {
        return vscode.window.showInputBox({ title: 'Label of the field', value: "Label" }).then(x => {
            return Object.assign(Object.assign({}, obj), { label: {
                    value: x || "Field Label"
                } });
        });
    }
    add(offset) {
        this.getFieldType().then(this.getFieldName).then(this.getFieldLabel)
            .then(value => {
            if (value !== null && value !== undefined) {
                const newField = Object.assign(Object.assign(Object.assign({}, defaults.all), (defaults[value.fieldType] ? defaults[value.fieldType] : {})), value);
                const newFieldString = JSON.stringify(newField, null, 2);
                this.editor.edit(editBuilder => {
                    const path = json.getLocation(this.text, offset.offset).path;
                    const index = path.pop();
                    path.push(index + 1);
                    const edits = json.modify(this.text, path, newField, { isArrayInsertion: true });
                    edits.forEach(e => {
                        const range = new vscode.Range(this.editor.document.positionAt(e.offset), this.editor.document.positionAt(e.offset + e.length));
                        editBuilder.replace(range, e.content);
                    });
                    vscode.commands.executeCommand('editor.action.formatDocument');
                    this.select(new vscode.Range(this.editor.document.positionAt(edits[0].offset), this.editor.document.positionAt(edits[0].offset + edits[0].length)));
                    setTimeout(() => {
                        this.parseTree();
                        this.refresh(offset);
                    }, 100);
                });
            }
        });
    }
    rename(offset) {
        vscode.window.showInputBox({ placeHolder: 'Enter the new label' })
            .then(value => {
            if (value !== null && value !== undefined) {
                this.editor.edit(editBuilder => {
                    const path = json.getLocation(this.text, offset.offset).path;
                    let fieldNode = json.findNodeAtLocation(this.tree, path);
                    let nameNode = this.getProperty(fieldNode, 'name');
                    if (nameNode) {
                        const range = new vscode.Range(this.editor.document.positionAt(nameNode.offset), this.editor.document.positionAt(nameNode.offset + nameNode.length));
                        editBuilder.replace(range, `"${value}"`);
                        setTimeout(() => {
                            this.parseTree();
                            this.refresh(offset);
                        }, 100);
                    }
                    else {
                        vscode.window.showErrorMessage("You need to first add a name property");
                    }
                });
            }
        });
    }
    onActiveEditorChanged() {
        if (vscode.window.activeTextEditor) {
            if (vscode.window.activeTextEditor.document.uri.scheme === 'file') {
                const enabled = vscode.window.activeTextEditor.document.languageId === 'json' || vscode.window.activeTextEditor.document.languageId === 'jsonc';
                vscode.commands.executeCommand('setContext', 'formTreeEnabled', enabled);
                if (enabled) {
                    this.refresh();
                }
            }
        }
        else {
            vscode.commands.executeCommand('setContext', 'formTreeEnabled', false);
        }
    }
    findFieldAtOffset(node) {
        return undefined;
        //todo: make this work
        if (node.offset == 0) {
            return this.getForm(this.tree)[0];
        }
        const obj = this.getProperty(node, ['type', 'name', 'fieldType', 'items']);
        if (obj !== undefined) {
            return {
                offset: node.offset,
                length: node.length,
                name: '$form',
                type: 'Form',
                hasItems: true
            };
        }
        if (node.parent) {
            return this.findFieldAtOffset(node);
        }
    }
    onDocumentChanged(changeEvent) {
        if (this.autoRefresh && changeEvent.document.uri.toString() === this.editor.document.uri.toString()) {
            for (const change of changeEvent.contentChanges) {
                const path = json.getLocation(this.text, this.editor.document.offsetAt(change.range.start)).path;
                path.pop();
                const node = path.length ? json.findNodeAtLocation(this.tree, path) : void 0;
                this.parseTree();
                this._onDidChangeTreeData.fire(this.findFieldAtOffset(node));
            }
        }
    }
    parseTree() {
        this.text = '';
        this.tree = null;
        this.editor = vscode.window.activeTextEditor;
        if (this.editor && this.editor.document) {
            this.text = this.editor.document.getText();
            const tree = json.parseTree(this.text);
            if (this.isForm(tree)) {
                this.tree = tree;
            }
        }
    }
    getChildren(offset) {
        let items = [];
        if (offset) {
            const path = json.getLocation(this.text, offset.offset).path;
            const node = json.findNodeAtLocation(this.tree, path);
            items = this.items(node);
        }
        else {
            items = this.tree ? this.getForm(this.tree) : [];
        }
        return Promise.resolve(items);
    }
    isElement(node) {
        return true;
    }
    getProperty(node, properties) {
        let props = properties;
        if (typeof props === 'string') {
            props = [props];
        }
        if (node.type === 'object') {
            const res = node.children.reduce((acc, x) => {
                const propertyName = x.children[0].value;
                const isRequired = x.type === 'property' && props.indexOf(propertyName) > -1;
                if (isRequired) {
                    acc[propertyName] = x.children[1];
                }
                return acc;
            }, {});
            if (Object.keys(res).length > 0) {
                if (typeof properties === 'string') {
                    return res[properties];
                }
                return res;
            }
        }
        return undefined;
    }
    isForm(node) {
        const adaptiveform = this.getProperty(node, 'adaptiveform');
        return node.type === 'object' && adaptiveform != null;
    }
    items(node) {
        const itemsNode = this.getProperty(node, 'items');
        return itemsNode.children.map(i => {
            var _a, _b, _c;
            const obj = this.getProperty(i, ['type', 'name', 'fieldType', 'items', "enum", "format"]);
            let fieldType;
            if (obj.fieldType === undefined) {
                const schema = {
                    type: (_a = obj.type) === null || _a === void 0 ? void 0 : _a.value,
                    enum: obj.enum ? json.getNodeValue(obj.enum) : undefined,
                    format: (_b = obj.format) === null || _b === void 0 ? void 0 : _b.value
                };
                fieldType = (0, utils_1.defaultFieldTypes)(schema);
            }
            else {
                fieldType = obj.fieldType.value;
            }
            if (obj != undefined) {
                return {
                    name: (_c = obj.name) === null || _c === void 0 ? void 0 : _c.value,
                    type: fieldType,
                    offset: i.offset,
                    length: i.length,
                    hasItems: obj.items !== undefined
                };
            }
        });
    }
    getForm(node) {
        const offset = {
            type: 'Form',
            name: '$form',
            offset: node.offset,
            length: node.length,
            hasItems: true
        };
        return [offset];
    }
    getTreeItem(field) {
        //const path = json.getLocation(this.text, offset).path;
        //const valueNode = json.findNodeAtLocation(this.tree, path);
        //if (valueNode) {
        const hasChildren = field.hasItems;
        const treeItem = new vscode.TreeItem(this.getLabel(field), hasChildren ? vscode.TreeItemCollapsibleState.Expanded : vscode.TreeItemCollapsibleState.None);
        treeItem.command = {
            command: 'extension.openJsonSelection',
            title: '',
            arguments: [new vscode.Range(this.editor.document.positionAt(field.offset), this.editor.document.positionAt(field.offset + field.length))]
        };
        treeItem.iconPath = this.getIcon(field);
        treeItem.contextValue = field.type;
        return treeItem;
        //}
        //return null;
    }
    select(range) {
        this.editor.selection = new vscode.Selection(range.start, range.end);
        this.editor.revealRange(range);
    }
    getIcon(node) {
        const nodeType = node.type;
        return {
            light: this.context.asAbsolutePath(path.join('resources', 'light', 'boolean.svg')),
            dark: this.context.asAbsolutePath(path.join('resources', 'dark', 'boolean.svg'))
        };
        if (nodeType === 'boolean') {
            return {
                light: this.context.asAbsolutePath(path.join('resources', 'light', 'boolean.svg')),
                dark: this.context.asAbsolutePath(path.join('resources', 'dark', 'boolean.svg'))
            };
        }
        if (nodeType === 'string') {
            return {
                light: this.context.asAbsolutePath(path.join('resources', 'light', 'string.svg')),
                dark: this.context.asAbsolutePath(path.join('resources', 'dark', 'string.svg'))
            };
        }
        if (nodeType === 'number') {
            return {
                light: this.context.asAbsolutePath(path.join('resources', 'light', 'number.svg')),
                dark: this.context.asAbsolutePath(path.join('resources', 'dark', 'number.svg'))
            };
        }
        return null;
    }
    getLabel(node) {
        return `${node.name} (${node.type})`;
    }
}
exports.FormTreeProvider = FormTreeProvider;
//# sourceMappingURL=formTree.js.map